@@ -220,7 +220,7 @@ static void draw_shadow (GtkStyle *style,
 			break;
 	}
 	
-	if (DETAIL ("button") && GTK_WIDGET_HAS_DEFAULT (widget))/* && !GTK_WIDGET_HAS_FOCUS (widget))*/
+	if (DETAIL ("buttondefault")) /* && !GTK_WIDGET_HAS_FOCUS (widget))*/
 	{
 		GdkGC *gc = style->base_gc[GTK_STATE_SELECTED];/*(LIGHTHOUSEBLUE_STYLE (style))->shade_gc[6];*/
 		theme_draw_rectangle (window, gc, FALSE, x + 3, y + 3, width - 7, height - 7);
@@ -251,8 +251,6 @@ static void draw_arrow (GtkStyle *style,
 						gboolean fill, gint x, gint y, gint width, gint height)
 {
 	GdkGC *fg_gc;
-	gint orig_width;
-	gint orig_height;
 	
 	g_return_if_fail (LIGHTHOUSEBLUE_IS_STYLE (style));
 	g_return_if_fail (window != NULL);
@@ -739,7 +737,7 @@ static void draw_check (GtkStyle *style,
 		gdk_gc_set_clip_rectangle (gc4, area);
 	}
 	
-	if (gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (widget)))
+	if (shadow_type == GTK_SHADOW_ETCHED_IN)
 	{
 		gdk_draw_line (window, gc1, x + 1, y + height, x + width - 2, y + height);
 		gdk_draw_line (window, gc1, x + width, y + 1, x + width, y + height - 2);
@@ -753,7 +751,7 @@ static void draw_check (GtkStyle *style,
 		gdk_draw_line (window, gc2, x + 1, y + height - 1, x + width - 2, y + height - 1);
 		gdk_draw_line (window, gc2, x + width - 1, y + 1, x + width - 1, y + height - 2);
 	}
-	else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
+	else if (shadow_type == GTK_SHADOW_IN)
 	{
 		gdk_draw_rectangle (window, gc3, TRUE, x + 1, y + 1,  width - 1, height - 1);
 		gdk_draw_line (window, gc2, x + 1, y, x + width - 1, y);
@@ -829,12 +827,12 @@ static void draw_option (GtkStyle *style,
 		gdk_gc_set_clip_rectangle (gc4, area);
 	}
 	
-	if (gtk_toggle_button_get_inconsistent (GTK_TOGGLE_BUTTON (widget)))
+	if (shadow_type == GTK_SHADOW_ETCHED_IN)
 	{
 		gdk_draw_arc(window, gc1, FALSE, x+1, y+1, width, height, 0, 360 * 64);
 		gdk_draw_arc(window, gc2, FALSE, x, y, width, height, 0, 360 * 64);
 	}
-	else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
+	else if (shadow_type == GTK_SHADOW_IN)
 	{
 		gdk_draw_arc(window, gc3, TRUE, x, y, width, height, 0, 360 * 64);
 		gdk_draw_arc(window, gc2, FALSE, x, y, width, height, 45 * 64, 225 * 64);
@@ -1293,7 +1291,7 @@ static void draw_focus (GtkStyle *style,
 		return;
 	}
 	
-	if (DETAIL ("button") && GTK_WIDGET_HAS_DEFAULT (widget))
+	if (DETAIL ("buttondefault"))
 	{
 		return; /* focus is represented by blue rectangle painted in draw_shadow */
 	}
@@ -1403,10 +1401,10 @@ static void draw_slider (GtkStyle *style,
 	
 	if (area)
 	{
-		gdk_gc_set_clip_rectangle (gc1, area);
-		gdk_gc_set_clip_rectangle (gc2, area);
-		gdk_gc_set_clip_rectangle (gc3, area);
-		gdk_gc_set_clip_rectangle (gc4, area);
+		gdk_gc_set_clip_rectangle (gc1, NULL);
+		gdk_gc_set_clip_rectangle (gc2, NULL);
+		gdk_gc_set_clip_rectangle (gc3, NULL);
+		gdk_gc_set_clip_rectangle (gc4, NULL);
 	}
 }
 				   
@@ -1496,7 +1494,7 @@ static void draw_handle (GtkStyle *style,
 			}
 		}
 		
-		return;
+		goto end;
 	}
 	else
 	{
@@ -1538,21 +1536,14 @@ static void draw_handle (GtkStyle *style,
 		}
 	}
 	
+end:
 	if (area)
 	{
 		gdk_gc_set_clip_rectangle (light_gc, NULL);
 		gdk_gc_set_clip_rectangle (dark_gc, NULL);
 	}
 }
-	
-static void draw_expander (GtkStyle * style,
-			 GdkWindow * window,
-			 GtkStateType state_type,
-			 GdkRectangle * area,
-			 GtkWidget * widget,
-			 const gchar * detail,
-			 gint x, gint y, GtkExpanderStyle expander_style){}
-				 
+
 static void draw_layout (GtkStyle *style,
 						 GdkWindow *window,
 						 GtkStateType state_type,
@@ -1573,7 +1564,7 @@ static void draw_layout (GtkStyle *style,
 	  
 	  context = pango_layout_get_context (layout);
       fontDescription = pango_context_get_font_description (context);
-	  if (pango_font_description_get_weight (fontDescription) != PANGO_WEIGHT_BOLD)
+	  if (widget && pango_font_description_get_weight (fontDescription) != PANGO_WEIGHT_BOLD)
 	  {
 		  parent = gtk_widget_get_parent (widget);
 
@@ -1780,6 +1771,20 @@ static void lighthouseblue_style_init_from_rc (GtkStyle *style, GtkRcStyle *rc_s
 	}
 }
 
+static void lighthouseblue_style_copy (GtkStyle *style, GtkStyle *src)
+{
+	LighthouseBlueStyle *lighthouseblue_style = LIGHTHOUSEBLUE_STYLE (style);
+	LighthouseBlueStyle *lighthouseblue_src = LIGHTHOUSEBLUE_STYLE (src);
+	gint i;
+	
+	for (i = 0; i < 8; i++)
+	{
+		lighthouseblue_style->shade[i] = lighthouseblue_src->shade[i];
+	}
+	
+	parent_class->copy (style, src);
+}
+
 static void lighthouseblue_style_realize (GtkStyle *style)
 {
 	LighthouseBlueStyle *lighthouseblue_style = LIGHTHOUSEBLUE_STYLE (style);
@@ -1815,6 +1820,7 @@ static void lighthouseblue_style_class_init (LighthouseBlueStyleClass *klass)
 
   parent_class = g_type_class_peek_parent (klass);
 
+  style_class->copy = lighthouseblue_style_copy;
   style_class->realize = lighthouseblue_style_realize;
   style_class->unrealize = lighthouseblue_style_unrealize;
   style_class->init_from_rc = lighthouseblue_style_init_from_rc;
@@ -1838,7 +1844,6 @@ static void lighthouseblue_style_class_init (LighthouseBlueStyleClass *klass)
 
   style_class->draw_focus = draw_focus;
 
-  /*style_class->draw_expander = draw_expander;*/
   style_class->draw_layout = draw_layout;
 
   style_class->draw_resize_grip = draw_resize_grip;
