@@ -61,7 +61,7 @@ redmond_draw_hline (GtkStyle * style,
             gint x2, 
             gint y)
 {
-  g_return_if_fail(sanitize_parameters(style, window, NULL, NULL));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, NULL, NULL));
  
   do_redmond_draw_line(window, 
                        style->dark_gc[state_type], 
@@ -87,10 +87,10 @@ redmond_draw_vline (GtkStyle * style,
             gint y2, 
             gint x)
 {
-  if (is_combo_box(widget, FALSE) && (!is_combo_box_entry(widget)))
+  if (redmond_is_combo_box(widget, FALSE) && (!redmond_is_combo_box_entry(widget)))
     return;
  
-  g_return_if_fail(sanitize_parameters(style, window, NULL, NULL));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, NULL, NULL));
  
   do_redmond_draw_line(window, 
                        style->dark_gc[state_type], 
@@ -131,7 +131,7 @@ redmond_draw_check (GtkStyle * style,
             gint width, 
             gint height)
 {
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
  
   /* Always draw the checkbox and mark centered
    * at a fixed size.
@@ -226,7 +226,7 @@ redmond_draw_option (GtkStyle * style,
 {
   RedmondStyle *redmond_style = REDMOND_STYLE (style);
  
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
  
   /* Since X arcs are very primitive and don't always
    * produce circles, we use bits here. Since the bits
@@ -321,17 +321,17 @@ redmond_draw_arrow (GtkStyle * style,
   gboolean button_in = (shadow == GTK_SHADOW_IN);
   gint child_offset_x = 1, child_offset_y = 1;
  
-  if (is_combo_box(widget, FALSE) && (!is_combo_box_entry(widget)))
+  if (redmond_is_combo_box(widget, FALSE) && (!redmond_is_combo_box_entry(widget)))
     return;
  
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
 
   if ((CHECK_DETAIL (detail, "spinbutton"))
       || (CHECK_DETAIL (detail, "vscrollbar"))
       || (CHECK_DETAIL (detail, "hscrollbar"))
       || (CHECK_DETAIL (detail, "optionmenu"))
       || IS_SCROLLBAR(widget)
-      || (is_in_combo_box (widget)))
+      || (redmond_is_in_combo_box (widget)))
     {
       if (state != GTK_STATE_INSENSITIVE)
         state = GTK_STATE_NORMAL;
@@ -341,7 +341,7 @@ redmond_draw_arrow (GtkStyle * style,
 	  if ((!widget) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR))
 	    x -= 1;
 	}
-      else if (is_in_combo_box (widget) && ((gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)))
+      else if (redmond_is_in_combo_box (widget) && ((gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)))
 	{
 	    x += 1;
 	}
@@ -350,7 +350,7 @@ redmond_draw_arrow (GtkStyle * style,
        * for ComboBox/ComboBoxEntry, because its cleaner,
        * even though it seems slightly inconsistant.
        */
-      if (widget && is_in_combo_box (widget))
+      if (widget && redmond_is_in_combo_box (widget))
 	{
 	  y += 1;
 	  width -= 2;
@@ -405,7 +405,7 @@ redmond_draw_shadow (GtkStyle * style,
 {
   RedmondStyle *redmond_style = REDMOND_STYLE (style);
  
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
  
   if (shadow_type == GTK_SHADOW_NONE)
     return;
@@ -463,7 +463,7 @@ redmond_draw_shadow (GtkStyle * style,
       else if (((CHECK_DETAIL (detail, "entry"))
 		|| (CHECK_DETAIL (detail, "frame")))
 	       && widget && ((IS_SPIN_BUTTON (widget))
-			     || (is_in_combo_box (widget))))
+			     || (redmond_is_in_combo_box (widget))))
 	{
 	  /* The Combo/ComboBoxEntry button and the SpingButton Steppers should apear
 	   * to be inset into the entry, as opposed to next to it, so we fake it
@@ -496,7 +496,7 @@ redmond_draw_shadow (GtkStyle * style,
 	       || ((IS_STATUS_BAR (widget)))
 	       || ((CHECK_DETAIL (detail, "frame")))
 	       || ((CHECK_DETAIL (detail, "button"))
-		   && (is_toolbar_item (widget))))
+		   && (redmond_is_toolbar_item (widget))))
 	{
 	  /* Toolbar Buttons, Status Bars, Frames, and Troughs are drawn with a thin border */
 	  do_redmond_draw_shadow (window, style->dark_gc[state_type],
@@ -521,7 +521,7 @@ redmond_draw_shadow (GtkStyle * style,
 	  || (CHECK_DETAIL (detail, "slider"))
 	  || (CHECK_DETAIL (detail, "spinbutton_up"))
 	  || (CHECK_DETAIL (detail, "spinbutton_down"))
-	  || ((CHECK_DETAIL (detail, "button")) && is_in_combo_box (widget)))
+	  || ((CHECK_DETAIL (detail, "button")) && redmond_is_in_combo_box (widget)))
 	{
 	  /* In the case of Scrollbars steppers, Sliders, Spinbutton steppers,
 	   * and Combo/ComboBoxEntry buttons, the internal & external borders are 
@@ -536,7 +536,7 @@ redmond_draw_shadow (GtkStyle * style,
 	}
       else if ((CHECK_DETAIL (detail, "frame"))
 	       || ((CHECK_DETAIL (detail, "button"))
-		   && (is_toolbar_item (widget))))
+		   && (redmond_is_toolbar_item (widget))))
 	{
 	  /* Toolbar Buttons and Frames are drawn with a thin border */
 	  do_redmond_draw_shadow (window, style->light_gc[state_type],
@@ -598,10 +598,10 @@ redmond_draw_combobox_button (GtkStyle * style,
 
   if ((!(widget)) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_LTR))
     {
-      if (is_combo_box_entry (widget)
-          || is_combo_box (widget, TRUE))
+      if (redmond_is_combo_box_entry (widget)
+          || redmond_is_combo_box (widget, TRUE))
         {
-          if (!is_combo_box_entry (widget))
+          if (!redmond_is_combo_box_entry (widget))
             {
               if ((widget->parent))
                 {
@@ -626,7 +626,7 @@ redmond_draw_combobox_button (GtkStyle * style,
           gtk_paint_shadow (style, window, state_type, GTK_SHADOW_IN,
   		            area, widget, "entry", x - 2, y, width, height);
         }
-      else if (is_combo(widget))
+      else if (redmond_is_combo(widget))
         {
           GtkWidget *entry = widget;
 
@@ -708,10 +708,10 @@ redmond_draw_combobox_button (GtkStyle * style,
     } 
   else
     {
-      if (is_combo_box_entry (widget)
-          || is_combo_box (widget, TRUE))
+      if (redmond_is_combo_box_entry (widget)
+          || redmond_is_combo_box (widget, TRUE))
         {
-          if (!is_combo_box_entry (widget))
+          if (!redmond_is_combo_box_entry (widget))
             {
               if ((widget->parent))
                 {
@@ -737,7 +737,7 @@ redmond_draw_combobox_button (GtkStyle * style,
           gtk_paint_shadow (style, window, state_type, GTK_SHADOW_IN,
 	  		    area, widget, "entry", x + 2, y, width, height);
         }
-      else if (is_combo(widget))
+      else if (redmond_is_combo(widget))
         {
           GtkWidget *entry = widget;
 
@@ -940,7 +940,7 @@ redmond_draw_box (GtkStyle * style,
 {
   RedmondStyle *redmond_style = REDMOND_STYLE (style);
  
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
  
   if (IS_MENU_SHELL(widget))
     {
@@ -1012,7 +1012,7 @@ redmond_draw_box (GtkStyle * style,
  
       if (((CHECK_DETAIL (detail, "dockitem_bin")) && 
            (IS_BONOBO_DOCK_ITEM(widget))) || 
-          ((widget) && (is_bonobo_dock_item(widget->parent))))
+          ((widget) && (redmond_is_bonobo_dock_item(widget->parent))))
 	{	  
 	  GList *children = NULL, *child = NULL;
 	  GtkWidget *dockitem = widget;
@@ -1166,7 +1166,7 @@ redmond_draw_box (GtkStyle * style,
        */
       if ((widget) && (widget->parent) &&
 	  ((!((CHECK_DETAIL (detail, "menubar")) && 
-	  is_panel_widget_item (widget)))))
+	  redmond_is_panel_widget_item (widget)))))
         {
           GdkRectangle shadow, clip;
           
@@ -1201,7 +1201,6 @@ redmond_draw_box (GtkStyle * style,
        * and a thin outset border on prelight
        */
       GdkGC *top, *bottom;
-      gboolean pressed = FALSE;
  
       if (state_type != GTK_STATE_INSENSITIVE)
 	state_type = GTK_STATE_NORMAL;
@@ -1243,7 +1242,7 @@ redmond_draw_box (GtkStyle * style,
                                     width, height);
     }
   else if ((CHECK_DETAIL (detail, "button")) && widget
-	   && is_in_combo_box (widget))
+	   && redmond_is_in_combo_box (widget))
     {
       /* ComboBox Buttons are an especially complex case
        * so call our special function for them.
@@ -1296,7 +1295,7 @@ redmond_draw_box (GtkStyle * style,
     }
  
   if (CHECK_DETAIL(detail, "optionmenu") ||  (CHECK_DETAIL(detail, "button") && 
-       (is_combo_box(widget, FALSE)) && !(is_combo_box_entry(widget))))
+       (redmond_is_combo_box(widget, FALSE)) && !(redmond_is_combo_box_entry(widget))))
     {
       GtkRequisition indicator_size;
       GtkBorder indicator_spacing;
@@ -1305,7 +1304,7 @@ redmond_draw_box (GtkStyle * style,
       if (state_type != GTK_STATE_INSENSITIVE)
         state_type = GTK_STATE_NORMAL;
  
-      option_menu_get_props (widget, &indicator_size, &indicator_spacing);
+      redmond_option_menu_get_props (widget, &indicator_size, &indicator_spacing);
  
       if ((!widget) || (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL))
 	vline_x = x + indicator_size.width + indicator_spacing.left + indicator_spacing.right;
@@ -1372,7 +1371,7 @@ redmond_draw_slider (GtkStyle * style,
              gint height, 
              GtkOrientation orientation)
 {
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
  
   if ((CHECK_DETAIL (detail, "hscale")) || (CHECK_DETAIL (detail, "vscale")))
     {
@@ -1419,7 +1418,7 @@ redmond_draw_extension (GtkStyle * style,
   GdkGC *gc3 = NULL;
   GdkGC *gc4 = NULL;
  
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
  
   do_redmond_draw_default_fill (style, window, GTK_STATE_NORMAL, area, 
                                 x, y, width, height);
@@ -1583,7 +1582,7 @@ redmond_draw_handle (GtkStyle * style,
 {
   gboolean left_cutoff = FALSE, right_cutoff = FALSE, top_cutoff = FALSE, bottom_cutoff = FALSE;
 
-  g_return_if_fail(sanitize_parameters(style, window, &width, &height));
+  g_return_if_fail(redmond_sanitize_parameters(style, window, &width, &height));
   
   if (IS_BONOBO_DOCK_ITEM_GRIP(widget) && 
      (gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL) && 
@@ -1641,13 +1640,13 @@ redmond_draw_handle (GtkStyle * style,
 	      if (width < height)
 		{
 		  orientation = GTK_ORIENTATION_HORIZONTAL;
-		  if (is_panel_widget_item (widget))
+		  if (redmond_is_panel_widget_item (widget))
 		    x += 2;
 		}
 	      else
 		{
 		  orientation = GTK_ORIENTATION_VERTICAL;
-		  if (is_panel_widget_item (widget))
+		  if (redmond_is_panel_widget_item (widget))
 		    y += 2;
 		}
 	    }
@@ -1674,7 +1673,7 @@ redmond_draw_handle (GtkStyle * style,
 			          height - style->ythickness - 3, FALSE);
 			          
         }
-      if (is_panel_widget_item (widget)
+      if (redmond_is_panel_widget_item (widget)
 	  && (CHECK_DETAIL (detail, "handlebox")
 	      && (!IS_HANDLE_BOX_ITEM (widget)))
 	  && (!(IS_HANDLE_BOX (widget))))
